@@ -1,3 +1,16 @@
+# Copyright (c) Yugabyte, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
+# in compliance with the License. You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software distributed under the License
+# is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
+# or implied. See the License for the specific language governing permissions and limitations
+# under the License.
+
+
 from typing import Dict, Union, Set, List
 
 import os
@@ -43,7 +56,8 @@ def is_valid_mypy_path_entry(path_entry: str) -> bool:
         os.path.basename(path_entry) != 'site-packages' and
         '/site-packages/' not in path_entry and
         # macOS-specific
-        '/Library/Frameworks/Python.framework/' not in path_entry
+        '/Library/Frameworks/Python.framework/' not in path_entry and
+        not os.path.exists(os.path.join(path_entry, 'typing.py'))
     )
 
 
